import platform
from typing import NamedTuple

CA = NamedTuple('CA', pk=int, name=str)


def ca_selector(api, msg) -> CA:
    """
    Get list of CAs to present to the user
    """
    try:
        root_cas = api.list()
    except Exception:
        raise SystemExit('Unable to retrieve available Certificate Authorities')

    cas = {}

    print('\nCertificate Authority list')

    for ca in root_cas.get('results', []):
        print(f'PK: {ca["pk"]} -- {ca["cn"]}')
        cas[ca["pk"]] = ca["cn"]

    print(f'\n{msg}\n')

    pk = None
    try:
        while not pk:
            entered_pk = input('Enter a Certificate Authority PK: ')
            try:
                int_pk = int(entered_pk)
            except Exception:
                print('\nInvalid Certificate Authority PK! Try again.\n')
                continue

            if int_pk in cas:
                pk = int_pk
            else:
                print(f'\nNo Certificate Authority found with PK of {int_pk}. Try again.\n')
    except (EOFError, KeyboardInterrupt):
        raise SystemExit()

    return CA(pk, cas[pk])


def install_ca_os(ctx, name, pem):
    """
    Install CA in Operating System
    """
    os_platform = platform.platform().lower()

    if 'linux' in os_platform:
        from .linux import linux_os, configure_browsers
        linux_os(ctx, name, pem)
        return configure_browsers(ctx, name)

    if 'macos' in os_platform:
        from .macos import mac_os, configure_browsers
        mac_os(ctx, name)
        return configure_browsers(ctx)

    print('Your OS is not yet supported')


__all__ = (
    'ca_selector',
    'install_ca_os',
)
