from lcconfig import AspenCtlSettingsConfig, ConsoleSettingsConfig as ConsoleSettingsConfigBase
from aspenctl import settings


class ConsoleSettingsConfig(ConsoleSettingsConfigBase):
    """
    Use this class everywhere to automatically read from the correct
    settings file, in the following order of priority:

       * /opt/sap/logcabin_portal/config/impersonator.conf
       * /etc/compass/settings.conf
       * /opt/sap/logcabin_portal/config/settings.conf
    """

    def __init__(self, *args, **kwargs):

        ctx = kwargs.pop('ctx', {})

        if settings.IS_IMPERSONATING:
            kwargs['config_settings'] = settings.IMPERSONATOR_FILE
            kwargs['persist_file'] = settings.IMPERSONATOR_FILE
        elif settings.IS_DRAWBRIDGE_FILTER:
            pass
        elif settings.IS_SERVER or ctx.get('dtype') == 'server':
            kwargs['config_settings'] = settings.COMPASS_CONFIG_FILE
            kwargs['persist_file'] = settings.COMPASS_CONFIG_FILE

        super().__init__(*args, **kwargs)


__all__ = (
    'AspenCtlSettingsConfig',  # convenience namespace
    'ConsoleSettingsConfig'
)
