from cryptography.hazmat.backends import default_backend
from cryptography.x509 import load_pem_x509_certificate, Certificate
from datetime import datetime, timedelta
from typing import Optional


def load_cert(location: str) -> Optional[Certificate]:
    """
    Load certificate from file location
    """
    try:
        with open(location, 'rb') as cf:
            data = cf.read()
            return load_pem_x509_certificate(
                data,
                backend=default_backend(),
            )
    except FileNotFoundError:
        return


def renewal_required(location: str) -> bool:
    """
    Check certificate to see if it's expired or nearly expired.
    """
    cert = load_cert(location)
    week_old = datetime.now() - timedelta(days=7)

    # If within a week of expiration, cert should be renewed.
    # to give flexible window for failed renewal attempts.
    return bool(cert) and cert.not_valid_after < week_old


__all__ = (
    'load_cert',
    'renewal_required',
)
