from cryptography.hazmat.backends import default_backend
from cryptography.hazmat.primitives import serialization
from cryptography.hazmat.primitives.asymmetric import rsa
import os

from aspenctl import settings


def generate_key(
    name,
    path='',
    public_exponent=65537,
    key_size=2048,
    backend=None,
) -> rsa.RSAPrivateKey:
    """
    Generate a Private key for the DrawBridge Console
    and save to the specified path
    """
    path = path or settings.ASPEN_CONFIG_DIR

    key = rsa.generate_private_key(
        public_exponent=public_exponent,
        key_size=key_size,
        backend=backend or default_backend(),
    )

    try:
        os.makedirs(f'{path}', exist_ok=True)
        with open(f'{path}/{name}.key', 'wb') as f:
            f.write(
                key.private_bytes(
                    encoding=serialization.Encoding.PEM,
                    format=serialization.PrivateFormat.TraditionalOpenSSL,
                    encryption_algorithm=serialization.NoEncryption(),
                )
            )
    except Exception as e:
        raise SystemExit(f'Unable to save {path}/{name}.key to disk: {e}')

    return key


__all__ = [
    'generate_key',
]
