"""
Settings related to DrawBridge filter servers.
"""
from pathlib import Path

try:
    from system_env.environment import setup_portal_environment, is_drawbridge_os
    IS_DRAWBRIDGE_OS = is_drawbridge_os()
    PORTAL_ENV = setup_portal_environment()
    CONF_DIR = PORTAL_ENV["CONF_DIR"]
except (ImportError, ModuleNotFoundError):
    IS_DRAWBRIDGE_OS = IS_IMPERSONATING = False
    PORTAL_ENV = {}
    CONF_DIR = ''

from .base import USERNAME

SSH_DIR = '/etc/ssh'

if IS_DRAWBRIDGE_OS:
    SSH_CONFIG_FILE = '/var/run/sshd/sshd_config'
    SSH_SERVICE_CMD = 'service ssh restart'
else:
    SSH_CONFIG_FILE = '/etc/ssh/sshd_config'
    SSH_SERVICE_CMD = 'service sshd restart'

COMPASS_COMPANY_CID = '1e75370c-f6e2-6de2-9123-f80f41f8bd97'
COMPASS_CONFIG_DIR = '/etc/compass'
COMPASS_CONFIG_FILE = f'{COMPASS_CONFIG_DIR}/settings.conf'
DRAWBRIDGE_CONFIG_FILE = f'{CONF_DIR}/settings.conf'
IMPERSONATOR_FILE = f'{CONF_DIR}/impersonator.conf'
ASPEN_CONFIG_DIR = f'{COMPASS_CONFIG_DIR}/aspenctl'

IS_DRAWBRIDGE_FILTER = IS_DRAWBRIDGE_OS or (
    Path(DRAWBRIDGE_CONFIG_FILE).exists() and USERNAME == 'root'
)
IS_IMPERSONATING = IS_DRAWBRIDGE_FILTER and Path(IMPERSONATOR_FILE).exists()
IS_SERVER = Path(COMPASS_CONFIG_FILE).exists() and USERNAME == 'root'

# Filters and infrastructure servers should not have all the tasks that are
# available to people's actual devices, so set flag based system properties.
IS_DRAWBRIDGE_OR_SERVER = IS_DRAWBRIDGE_FILTER or IS_SERVER

HOST_RENEWAL_MARGIN_DAYS = 14
