from invoke import task
from lcconfig import AspenCtlSettingsConfig
from pathlib import Path
from string import punctuation

from ...encryption import purge_keyring_secrets
from ...ssh import clear_sshd_config_file, purge_ssh_identity_keys
from .server import register as register_server
from .device import register as register_device
from ..renew import host_identity_key
from ...settings import IS_DRAWBRIDGE_FILTER

table = str.maketrans(punctuation, ' ' * len(punctuation))
default_dtype = 'server' if IS_DRAWBRIDGE_FILTER else 'device'


@task(
    help={'dtype': f'System type - "server" or "device". "{default_dtype}" is default.'},
    post=[host_identity_key],
)
def register(ctx, dtype=default_dtype):
    """
    Register this Server or Device on Aspen.
    """
    ctx['dtype'] = dtype
    if dtype == 'device':
        return register_device(ctx)

    return register_server(ctx)


@task
def unregister(ctx):
    """
    Delete all Aspen-related SSH identities and secrets on this device.
    """
    purge_ssh_identity_keys(ctx)
    purge_keyring_secrets(ctx)
    purge_aspen_config()
    clear_sshd_config_file(ctx)

    print('Successfully unregistered this device')


def purge_aspen_config():
    """
    Delete Aspen configuration file(s) from this device / server.
    """
    try:
        # use missing_ok=True when dropping support for 3.7
        Path(AspenCtlSettingsConfig.persist_file).expanduser().unlink()
    except FileNotFoundError:
        pass


__all__ = (
    'register',
    'unregister',
    'purge_aspen_config',
)
