from lcconfig import AspenCtlSettingsConfig
from invoke import task
from pathlib import Path

from aspenctl.network import get_api
from aspenctl import settings
from aspenctl.ssh import refresh_user_key, expired_ssh_certificate


@task(name='user', help={'force': 'Renew whether expired or not'})
def user_identity_key(ctx, force=False):
    """
    Get or renew a signed User Identity Key for your account on this device.

    This will completely remove your current Private and Public keys.
    """
    if not force:
        cert_path = f'~/.ssh/{settings.USER_KEY_NAME}-cert.pub'
        expired, cert = expired_ssh_certificate(Path(cert_path).expanduser())
        if not expired:
            print(
                f'Skipping renewal - current certificate is valid till {cert.valid_before}.\n'
                f'To renew anyway, pass in the --force flag.'
            )
            return

    print('Get or renew SSH identity key for User on this device')

    cfg = AspenCtlSettingsConfig()
    cfg_data = cfg.as_typed_dict(settings.DEVICE_SECTION)

    try:
        device_cid = cfg_data['cid']
    except KeyError:
        print('Device is not yet registered. Attempting to register now.')
        from aspenctl.tasks.register.device import register
        register(ctx)
        return user_identity_key(ctx)

    api, _ = get_api(ctx)
    api.load('devices', 'device')

    refresh_user_key(ctx, device_cid, api)


__all__ = [
    'user_identity_key',
]
