from invoke import task
from pathlib import Path

from aspenctl import settings
from aspenctl.ssh import (
    add_private_key_identity,
    expired_ssh_certificate,
)


@task(name='add')
def add_key(ctx):
    """
    Add private key to your available SSH Identities.
    """
    from ..renew import user_identity_key
    key_path = Path(f'~/.ssh/{settings.USER_KEY_NAME}').expanduser()

    if not key_path.exists():
        print('No identity keys found; retrieving first SSH keys from Aspen.')
        user_identity_key(ctx, force=True)
    else:
        cert_path = Path(f'~/.ssh/{settings.USER_KEY_NAME}-cert.pub').expanduser()
        expired, _ = expired_ssh_certificate(cert_path)
        if expired:
            print('Current signed certificate is expired; renewing now.')
            user_identity_key(ctx, force=True)

    add_private_key_identity(ctx, key_path)


__all__ = [
    'add_key',
]
