from invoke import task
from pathlib import Path

from aspenctl import settings


@task(help={'cert_type': 'Type of SSH Identity key to view (user / host).'})
def view(ctx, cert_type='user'):
    """
    View SSH identity certificate details. "user" is default. Pass in "host"
    to view system host identity details.
    """
    cert_type = cert_type.lower()
    if cert_type not in ('user', 'host'):
        raise SystemExit('Invalid identity certificate type. Please enter "user" or "host"!')

    if cert_type == 'user':
        key_path = Path(f'~/.ssh/{settings.USER_KEY_NAME}-cert.pub').expanduser()
    else:
        key_path = Path(f'{settings.SSH_DIR}/{settings.HOST_KEY_NAME}.pub')

    if not key_path.exists():
        raise SystemExit(f'{cert_type!r} Identity Key is not found')

    return ctx.run(f'ssh-keygen -L -f {key_path}')


__all__ = [
    'view',
]
