import os
from invoke import task
from aspenctl.network import get_api
from aspenctl.authorities import ca_selector, install_ca_os
from aspenctl.settings import HOME_DIR


@task
def install_ca(ctx):
    """
    Install all Certificate Authorities into OS's Trusted CA store.
    """
    api, _ = get_api(ctx)
    api.load('aspentls', 'rootcertificateauthority')

    ca_pk, ca_name = ca_selector(api, 'Select a Root CA to install')
    print('\nSelect a Root CA to install\n')

    try:
        resp = api.get(ca_pk, subpath='get_public_key_chain')
    except Exception as e:
        print(f'Unable to retrieve public key: {e}')
        return

    pem = resp.json().get('pem')
    ca_name = ca_name.replace(' ', '')

    # ------------------------------------------------------------
    # Save public key various pertinent locations
    os.makedirs(HOME_DIR, exist_ok=True)

    ctx['cert_path'] = f"{HOME_DIR}/{ca_name}.pem"

    with open(ctx['cert_path'], 'w') as pf:
        pf.write(pem)

    install_ca_os(ctx, ca_name, pem)

    print(f"Installed CA Cert and saved to {ctx['cert_path']}")


@task
def update(ctx):  # noqa
    """
    Steps to update Aspen Ctl on this device.
    """
    print('\nTo update Aspen Ctl on this device, run the following commands:\n')
    print('pip3 install -U aspenctl')
    print('\n')


__all__ = (
    'install_ca',
    'update',
)
